# Getting Started


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

``` python
from fast_snippets import health_check, version
```

``` python
health_check()
```

    The application is healthy!

``` python
version()
```

    fast_snippets version: 0.1.1

You can also check out the CLI in by running

``` bash
$ fs
```

                                                                                    
     Usage: fs [OPTIONS] COMMAND [ARGS]...                                          
                                                                                    
     Fast Snippets for Pytorch, Computer Vision, Deep Learning and Python in        
     General                                                                        
                                                                                    
    ╭─ Options ────────────────────────────────────────────────────────────────────╮
    │ --install-completion          Install completion for the current shell.      │
    │ --show-completion             Show completion for the current shell, to copy │
    │                               it or customize the installation.              │
    │ --help                        Show this message and exit.                    │
    ╰──────────────────────────────────────────────────────────────────────────────╯
    ╭─ Commands ───────────────────────────────────────────────────────────────────╮
    │ health-check   Check the health of the application.                          │
    │ version        Print the version of the application.                         │
    ╰──────────────────────────────────────────────────────────────────────────────╯

    CompletedProcess(args=['/Users/yeshwanth/Code/Personal/fast_snippets/.venv/bin/fs'], returncode=2)

in shell
